==> mule-datasense-4.1.6-sources.jar: org/mule/datasense/impl/phases/annotators/TransformAnnotator.java <==
package org.mule.datasense.impl.phases.annotators;

import org.mule.datasense.impl.model.annotations.MuleEventExprAnnotation;
import org.mule.datasense.impl.model.ast.MessageProcessorNode;
import org.mule.datasense.impl.model.event.MuleEventExpr;
import org.mule.datasense.impl.model.event.MuleEventExprBuilder;
import org.mule.datasense.impl.phases.typing.AnnotatingMuleAstVisitorContext;
import org.mule.datasense.impl.phases.typing.resolver.transform.TransformParser;
import org.mule.datasense.impl.util.ComponentIdentifierUtils;

import static org.mule.datasense.impl.DefaultDataSense.COMPONENT_IDENTIFIER_TRANSFORM;

public class TransformAnnotator extends BaseAnnotator {

  private final TransformParser transformParser;

  public TransformAnnotator() {
    transformParser = new TransformParser();
  }

  @Override
  public void annotate(MessageProcessorNode messageProcessorNode,
                       AnnotatingMuleAstVisitorContext annotatingMuleAstVisitorContext) {
    if (COMPONENT_IDENTIFIER_TRANSFORM
        .equals(ComponentIdentifierUtils.createFromComponentModel(messageProcessorNode.getComponentModel()))) {
      MuleEventExprBuilder muleEventExprBuilder =
          transformParser.parse(messageProcessorNode.getComponentModel(),
                                annotatingMuleAstVisitorContext.getDataSenseProviderResolver().getResourceResolver(),
                                annotatingMuleAstVisitorContext.getAstNotification(), messageProcessorNode.getAstNodeLocation());
      MuleEventExpr muleEventExpr = muleEventExprBuilder.build();
      messageProcessorNode.annotate(new MuleEventExprAnnotation(muleEventExpr));
    }
  }
}

==> mule-datasense-4.5.0-20220922-sources.jar: org/mule/datasense/impl/phases/annotators/TransformAnnotator.java <==
package org.mule.datasense.impl.phases.annotators;

import org.mule.datasense.impl.model.annotations.MuleEventExprAnnotation;
import org.mule.datasense.impl.model.ast.MessageProcessorNode;
import org.mule.datasense.impl.model.event.MuleEventExpr;
import org.mule.datasense.impl.model.event.MuleEventExprBuilder;
import org.mule.datasense.impl.phases.typing.AnnotatingMuleAstVisitorContext;
import org.mule.datasense.impl.phases.typing.resolver.transform.TransformParser;
import org.mule.datasense.impl.util.ComponentIdentifierUtils;

import static org.mule.datasense.impl.DefaultDataSense.COMPONENT_IDENTIFIER_TRANSFORM;

public class TransformAnnotator extends BaseAnnotator {

  private final TransformParser transformParser;

  public TransformAnnotator() {
    transformParser = new TransformParser();
  }

  @Override
  public void annotate(MessageProcessorNode messageProcessorNode,
                       AnnotatingMuleAstVisitorContext annotatingMuleAstVisitorContext) {
    if (COMPONENT_IDENTIFIER_TRANSFORM
        .equals(messageProcessorNode.getComponentModel().getIdentifier())) {
      MuleEventExprBuilder muleEventExprBuilder =
          transformParser.parse(messageProcessorNode.getComponentModel(),
                                annotatingMuleAstVisitorContext.getDataSenseProviderResolver().getResourceResolver(),
                                annotatingMuleAstVisitorContext.getAstNotification(), messageProcessorNode.getAstNodeLocation());
      MuleEventExpr muleEventExpr = muleEventExprBuilder.build();
      messageProcessorNode.annotate(new MuleEventExprAnnotation(muleEventExpr));
    }
  }
}
